@@ -98,4 +98,13 @@ def _set_file(
 logger.set_file = MethodType(_set_file, logger)
 setattr(logger, "set_level", lambda level: logzero.loglevel(level))
 
+logger.CRITICAL = CRITICAL
+logger.ERROR    = ERROR
+logger.WARNING  = WARNING
+logger.INFO     = INFO
+logger.DEBUG    = DEBUG
+logger.SUCCESS  = SUCCESS
+logger.VERBOSE  = VERBOSE
+logger.TRACE    = TRACE
+
 sys.excepthook = lambda e, v, tb: logger.critical(f"Uncaught Exception ➔ {e.__name__}: {v}", exc_info=(e, v, tb))
